@@ -1,5 +1,5 @@
 package Selenium::Chrome;
-$Selenium::Chrome::VERSION = '1.02';
+$Selenium::Chrome::VERSION = '1.10';
 # ABSTRACT: Use ChromeDriver without a Selenium server
 use Moo;
 use Selenium::CanStartBinary::FindBinary qw/coerce_simple_binary/;
@@ -54,7 +54,7 @@ Selenium::Chrome - Use ChromeDriver without a Selenium server
 
 =head1 VERSION
 
-version 1.02
+version 1.10
 
 =head1 SYNOPSIS
 
@@ -117,6 +117,11 @@ up to 20 seconds:
 
 See L<Selenium::CanStartBinary/startup_timeout> for more information.
 
+=head2 fixed_ports
+
+Optional: Throw instead of searching for additional ports; see
+L<Selenium::CanStartBinary/fixed_ports> for more info.
+
 =head1 METHODS
 
 =head2 shutdown_binary
